package td02;

public class Complexe {
	private double a;
	private double b;

	public Complexe() {
		this(0, 0);
	}

	public Complexe(double re, double im) {
		a = re;
		b = im;
	}

	public String toString() {
		if (a == 0.0 || b == 0.0) {
			if (a == 0.0)
				return b + " i";
			else
				return "" + a;
		}
		return a + " + " + b + " i";
	}

	public double getPartieReelle() {
		return a;
	}

	public double getPartieImaginaire() {
		return b;
	}

	public boolean equals(Complexe z) {
		return (a == z.a) && (b == z.b);
	}

	/**
	 * Calcule le module du complexe 
	 * 
	 * @return la somme des carres de la partie reelle et de la partie
	 *         imaginaire
	 */
	private double sommeDesCarres() {
		return (a * a + b * b);
	}

	public double module() {
		return Math.sqrt(sommeDesCarres());
	}

	/**
	 * Ajoute au complexe courant le complexe z. Cette methode ne retourne pas
	 * de resultat car elle modifie le complexe courant (c'est ce que l'on
	 * appelle un <em>effet de bord</em>, car on modifie l'etat de l'objet).
	 * 
	 * @param z
	 *            le complexe a ajouter
	 */
	public void ajouter(Complexe z) {
		a += z.a;
		b += z.b;
	}

	/**
	 * Retourne un nouveau complexe representant l'addition des complexes passés
	 * en parametre. Contrairement aux methodes <em>ajouter</em>, cette methode
	 * ne provoque pas d'effets de bord et retourne un nouvel objet.
	 * 
	 * @param x
	 *            un des complexes a ajouter
	 * @param y
	 *            un des complexes a ajouter
	 * @return la somme des complexes
	 */
	public static Complexe addition(Complexe x, Complexe y) {
		return new Complexe(x.getPartieReelle() + y.getPartieReelle(), 
				x.getPartieImaginaire() + y.getPartieImaginaire());
	}

	/**
	 * Retourne un nouveau complexe representant la multiplication des 2
	 * complexes
	 * 
	 * @param x
	 *            un complexe à multiplier
	 * @param y
	 *            un complexe à multiplier
	 * @return le resultat de la multiplication des 2 complexes
	 */
	public static Complexe multiplication(Complexe x, Complexe y) {
		return new Complexe(x.getPartieReelle() * y.getPartieReelle()
				- x.getPartieImaginaire() * y.getPartieImaginaire(), 
				x.getPartieReelle()	* y.getPartieImaginaire()
				+ y.getPartieReelle() * x.getPartieImaginaire());
	}

}
